summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/enum.h
diff options
context:
space:
mode:
Diffstat (limited to 'crawl-ref/source/enum.h')
-rw-r--r--crawl-ref/source/enum.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/crawl-ref/source/enum.h b/crawl-ref/source/enum.h
index 14581e94a0..bbdfad70a9 100644
--- a/crawl-ref/source/enum.h
+++ b/crawl-ref/source/enum.h
@@ -2789,7 +2789,8 @@ enum montravel_target_type
MTRAV_NONE = 0,
MTRAV_PLAYER, // Travelling to reach the player.
MTRAV_PATROL, // Travelling to reach the patrol point.
- MTRAV_UNREACHABLE // Not travelling because player is unreachable.
+ MTRAV_UNREACHABLE, // Not travelling because player is unreachable.
+ MTRAV_EXIT // Travelling to reach a level exit.
};
#ifdef WIZARD